@@ -1,8 +1,8 @@
 from __future__ import annotations
 
-import click
 import ckan.model as model
 import ckan.plugins.toolkit as tk
+import click
 
 
 def get_commands():
@@ -15,8 +15,12 @@ def check_link():
 
 
 @check_link.command()
-@click.option("-d", "--include-draft", is_flag=True, help="Check draft packages as well")
-@click.option("-p", "--include-private", is_flag=True, help="Check private packages as well")
+@click.option(
+    "-d", "--include-draft", is_flag=True, help="Check draft packages as well"
+)
+@click.option(
+    "-p", "--include-private", is_flag=True, help="Check private packages as well"
+)
 @click.argument("ids", nargs=-1)
 def check_packages(include_draft: bool, include_private: bool, ids: tuple[str, ...]):
     """Check every resource inside each package.
@@ -40,7 +44,7 @@ def check_packages(include_draft: bool, include_private: bool, ids: tuple[str, .
         q = q.filter(model.Package.private == False)
 
     if ids:
-        q = q.filter(model.Package.id.in_(ids))
+        q = q.filter(model.Package.id.in_(ids) | model.Package.name.in_(ids))
 
     with click.progressbar(q, length=q.count()) as bar:
         for pkg in bar:
